@@ -107,7 +107,7 @@ class GeWebsocketClient(GeBaseClient):
         """Run the client."""
         try:
             await self._set_state(GeClientState.CONNECTING)
-            async with websockets.connect(self.endpoint) as socket:
+            async with websockets.connect(self.endpoint, compression=None) as socket:
                 self._socket = socket
                 self._setup_futures()
                 await self._subscribe_all()
@@ -267,6 +267,9 @@ class GeWebsocketClient(GeBaseClient):
             else:
                 _LOGGER.debug(f"Unknown message received: {message_dict}")
 
+        #added per #867 in websocket project        
+        await asyncio.sleep(0)
+
     async def _process_appliance_list(self, message_dict: Dict):
         """
         Process the appliance list.
@@ -422,7 +425,12 @@ class GeWebsocketClient(GeBaseClient):
             if not self.websocket:
                 raise websockets.ConnectionClosedOK(1001, 'Socket disconnected')    
 
+            #send the payload
             await self.websocket.send(payload)
+
+            #added per #867 in websocket project   
+            await asyncio.sleep(0)
+
         except websockets.ConnectionClosed:
             _LOGGER.info("Tried to send a message, but connection already closed.")
 
