@@ -8,4 +8,4 @@ class ErdOnOff(enum.Enum):
     NA = "FF"
 
     def boolify(self) -> Optional[bool]:
-        return self.value == ErdOnOff.ON   
\ No newline at end of file
+        return self == ErdOnOff.ON   
\ No newline at end of file
