@@ -29,12 +29,6 @@ class ErdMicrowaveCookMode(enum.Enum):
     WARM_BROIL_HIGH = "WARM_BROIL_HIGH"
     DASH = "FF"
 
-@enum.unique
-class ErdMicrowaveDoorStatus(enum.Enum):
-    CLOSED = "00"
-    OPEN = "01"
-    NA = "FF"
-
 @enum.unique
 class ErdMicrowaveCookStatus(enum.Enum):
     OFF = "00"
